import boto3
from .datetime_utils import convert_time_t_to_useastern_datetime_string

def aws_get_log_groups(sort: str = None):
    result = []
    if not sort:
        sort_field = "created"
        sort_descending = True
    else:
        if sort.endswith(".desc"):
            sort = "-" + sort[:-5]
            sort_descending = True
        elif sort.endswith(".asc"):
            sort_descending = False
            sort = sort[:-4]
        else:
            sort_descending = False
        if sort == "timestamp":
            sort_field = "created"
        else:
            sort_field = "name"
    logs = boto3.client("logs")
    paginator = logs.get_paginator('describe_log_groups')
    for page in paginator.paginate():
        for group in page['logGroups']:
            created = (group.get("creationTime") or 0) // 1000
            result.append({
                "name": group.get("logGroupName"),
                "arn": group.get("arn"),
                "created": convert_time_t_to_useastern_datetime_string(created)
            })
    result.sort(key=lambda value: value[sort_field], reverse=True if sort_descending else False)
    return result
